@@ -21,7 +21,7 @@ sub ProcessKodakPatch($$$);
 sub WriteUnknownOrPreview($$$);
 sub FixLeicaBase($$;$);
 
-$VERSION = '1.96';
+$VERSION = '1.97';
 
 my $debug;          # set to 1 to enable debugging code
 
@@ -586,8 +586,8 @@ my $debug;          # set to 1 to enable debugging code
         # (X1 starts with "LEICA\0\x01\0", Make is "LEICA CAMERA AG")
         # (X2 starts with "LEICA\0\x05\0", Make is "LEICA CAMERA AG")
         # (X VARIO starts with "LEICA\0\x04\0", Make is "LEICA CAMERA AG")
-        # (T (Typ 701) starts with LEICA\0\0x6", Make is "LEICA CAMERA AG")
-        # (X (Typ 113) starts with LEICA\0\0x7", Make is "LEICA CAMERA AG")
+        # (T (Typ 701) starts with "LEICA\0\0x6", Make is "LEICA CAMERA AG")
+        # (X (Typ 113) starts with "LEICA\0\0x7", Make is "LEICA CAMERA AG")
         Condition => '$$valPt =~ /^LEICA\0[\x01\x04\x05\x06\x07]\0/',
         SubDirectory => {
             TagTable => 'Image::ExifTool::Panasonic::Leica5',
@@ -633,6 +633,28 @@ my $debug;          # set to 1 to enable debugging code
             Base => '-$base',  # uses absolute file offsets
         },
     },
+    {
+        Name => 'MakerNoteLeica8', # used by the Q (Type 116)
+        # (Q (Typ 116) starts with "LEICA\0\x08\0", Make is "LEICA CAMERA AG")
+        # (SL (Typ 601) starts with "LEICA\0\x09\0", Make is "LEICA CAMERA AG")
+        Condition => '$$valPt =~ /^LEICA\0[\x08\x09]\0/',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Panasonic::Leica5',
+            Start => '$valuePtr + 8',
+            ByteOrder => 'Unknown',
+        },
+    },
+    {
+        Name => 'MakerNoteLeica9', # used by the M9/M-Monochrom
+        # (M9 and M Monochrom start with "LEICA0\x03\0")
+        Condition => '$$self{Make} =~ /^Leica Camera AG/ and $$valPt =~ /^LEICA\0\x02\0/',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Panasonic::Leica9',
+            Start => '$valuePtr + 8',
+            Base => '$start - 8',
+            ByteOrder => 'Unknown',
+        },
+    },
     {
         Name => 'MakerNotePanasonic',
         # (starts with "Panasonic\0")
@@ -910,7 +932,7 @@ my $debug;          # set to 1 to enable debugging code
         # (starts with "SONY PIC\0" -- DSC-H200/J20/W370/W510, MHS-TS20)
         Condition => '$$valPt=~/^SONY PIC\0/',
         SubDirectory => { TagTable => 'Image::ExifTool::Sony::PIC' },
-    },    
+    },
     {
         Name => 'MakerNoteSony5', # used in SR2 and ARW images
         Condition => '$$self{Make}=~/^SONY/ and $$valPt!~/^\x01\x00/',
@@ -1352,7 +1374,7 @@ sub LocateIFD($$)
 #
     if ($tagInfo and $$tagInfo{SubDirectory}) {
         my $subdir = $$tagInfo{SubDirectory};
-        unless ($$subdir{ProcessProc} and 
+        unless ($$subdir{ProcessProc} and
                ($$subdir{ProcessProc} eq \&ProcessUnknown or
                 $$subdir{ProcessProc} eq \&ProcessUnknownOrPreview))
         {
